@@ -357,7 +357,11 @@ class BinoutData(object):
         '''
         ids = self.get_channels_ids_object_name(json_object[JsonConstants.ID_UPPER_CASE], self._name)
 
-        assert(len(ids) != 0), self._logger.emit(LOGConstants.ERROR[0], "ID not in binout")
+        if (len(ids) == 0):
+            if "ID" in json_object:
+                self._logger.emit(LOGConstants.ERROR[0], "Missing ID in the input data with identifier: " + json_object["ID"])
+
+            return
 
         array_definition = json_object[JsonConstants.ARRAY]
 
@@ -393,7 +397,10 @@ class BinoutData(object):
         """
         if channel_name == 'time':
             return self._time_interp.reshape(-1, 1)
-        data_index = np.where(int(id) == self._ids)[0]
+        if np.issubdtype(self._ids.dtype, np.number):
+            data_index = np.where(int(id) == self._ids)[0]
+        else:  # madymo case
+            data_index = np.where(id == self._ids)[0]
 
         if len(data_index) == 0:
             self._logger.emit(LOGConstants.ERROR[0], 'ID ' + str(id) + ' not in binout')
