@@ -2,7 +2,7 @@ import time
 import json
 
 from ..utils.constants import LOGConstants, DefFileConstants, UnitsConstants, DefinitionConstants, \
-    ObjectConstantsForData, JsonConstants, LoggerERROR, LoggerWARNING, CodeType, PluginsParamDictDef
+    ObjectConstantsForData, JsonConstants, LoggerERROR, LoggerWARNING, PluginsParamDictDef
 from ..utils.constants import LoggerReadDynasaurDefinitionFile as LD
 from ..data.def_file_validator import TestDefinitionJSON
 
@@ -73,7 +73,6 @@ class DynasaurDefinitions:
         self._title = ''
         self._objects = {}
         self._logger = logger
-        self._code = CodeType.BINOUT
         self._info = []
 
         # set all class members
@@ -147,14 +146,6 @@ class DynasaurDefinitions:
             exit("Exiting, check your def file")
         return self._data_vis[key]
 
-    def get_code(self):
-        '''
-        get code
-
-        :param:
-        :return code:
-        '''
-        return self._code
 
     def get_ids_from_name(self, name, data_container, plugin_name):
         '''
@@ -505,12 +496,9 @@ class DynasaurDefinitions:
                 self._set_info()
             elif DefinitionConstants.OBJECTS in j_object:
                 self._parse_objects(json_objects)
-            elif DefinitionConstants.CODE in j_object:
-                self._code = j_object[DefinitionConstants.CODE]
             else:
                 self._logger.emit(LOGConstants.ERROR[0], "json object not understood:" + str(j_object))
                 return
 
-        print(self._energy_global)
         self._logger.emit(LOGConstants.READ_DYNASAUR_DEF[0], LD.DONE)
 
