@@ -4,9 +4,8 @@ from enum import Enum
 import numpy as np
 import time as t
 
-from ..utils.constants import LOGConstants, CodeType
+from ..utils.constants import LOGConstants
 from ..data.data_interface import BinoutData
-from ..data.madymo import Madymo
 
 
 class DEForc(BinoutData):
@@ -1069,7 +1068,7 @@ class Matsum(BinoutData):
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'matsum')
 
 
-class Nodout(BinoutData, Madymo):
+class Nodout(BinoutData):
     '''
     '''
     DATA_CHANNEL_TYPES = ['rx_velocity', 'ry_velocity', 'rz_velocity', 'rx_displacement', 'ry_displacement',
@@ -1079,7 +1078,7 @@ class Nodout(BinoutData, Madymo):
                           'z_acceleration']
     ids_name = "ids"
 
-    def __init__(self, data, logger, dynasaur_definitions, code_type):
+    def __init__(self, data, logger, dynasaur_definitions):
         '''
         Initialization/constructor
 
@@ -1090,54 +1089,41 @@ class Nodout(BinoutData, Madymo):
 
         :return:
         '''
-        self._code_type = code_type
+        #self._code_type = code_type
 
-        if code_type == CodeType.BINOUT:
-            BinoutData.__init__(self, data, logger, dynasaur_definitions, 'nodout')
-        else:
-            Madymo.__init__(self, data, logger, dynasaur_definitions, 'nodout')
+        BinoutData.__init__(self, data, logger, dynasaur_definitions, 'nodout')
 
-    def get_channels_ids_object_name(self, object_name, plugin_name):
-        '''
-        Get channels ids with given object name and plugin name
+    # def get_channels_ids_object_name(self, object_name, plugin_name):
+    #     '''
+    #     Get channels ids with given object name and plugin name
+    #
+    #     :param: object_name
+    #     :param: plugin_name
+    #
+    #     :return channel ids:
+    #     '''
+    #     return BinoutData.get_channels_ids_object_name(self, object_name, plugin_name)
 
-        :param: object_name
-        :param: plugin_name
+    # def get_measurement_channel(self, id, channel_name):
+    #     '''
+    #     Get measurement channel with given id and channel name
+    #
+    #     :param: id
+    #     :param: channel_name
+    #
+    #     :return measurement channel:
+    #     '''
+    #     return BinoutData.get_measurement_channel(self, id, channel_name)
 
-        :return channel ids:
-        '''
-        #if self._code_type == CodeType.BINOUT:
-        return BinoutData.get_channels_ids_object_name(self, object_name, plugin_name)
-        #else:
-        #    return Madymo.get_channels_ids_object_name(self, object_name, plugin_name)
-
-    def get_measurement_channel(self, id, channel_name):
-        '''
-        Get measurement channel with given id and channel name
-
-        :param: id
-        :param: channel_name
-
-        :return measurement channel:
-        '''
-
-        #if self._code_type == CodeType.BINOUT:
-        return BinoutData.get_measurement_channel(self, id, channel_name)
-        #else:
-        #    return Madymo.get_measurement_channel(self, id, channel_name)
-
-    def get_time(self):
-        '''
-        Get time
-
-        :param:
-
-        :return time:
-        '''
-        #if self._code_type == CodeType.BINOUT:
-        return BinoutData.get_interpolated_time(self)
-        #else:
-        #    return Madymo.get_time(self)
+    # def get_time(self):
+    #     '''
+    #     Get time
+    #
+    #     :param:
+    #
+    #     :return time:
+    #     '''
+    #     return BinoutData.get_interpolated_time(self)
 
 
 class RCForc(BinoutData):
