@@ -151,9 +151,9 @@ class ObjectConstantsForData:
 
 
 
-class CodeType:
-    MADYMO = "MADYMO"
-    BINOUT = "LS_DYNA"
+# class CodeType:
+#     MADYMO = "MADYMO"
+#     BINOUT = "LS_DYNA"
 
 
 class JsonConstants:
@@ -359,7 +359,7 @@ class VPSDataConstant:
 class DataChannelTypesNodout:
     X_COORDINATE = "x_coordinate"
     Y_COORDINATE = "y_coordinate"
-    Z_COORDINATE = "Z_coordinate"
+    Z_COORDINATE = "z_coordinate"
 
     X_DISPLACEMENT = "x_displacement"
     Y_DISPLACEMENT = "y_displacement"
